@@ -1,8 +1,10 @@
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/pm/TestHelper.pm,v 1.11 2005/11/13 18:29:33 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/pm/TestHelper.pm,v 1.13 2008/09/06 20:11:03 kaffeetisch Exp $
 #
 
 package Gtk2::TestHelper;
+use strict;
+use warnings;
 use Test::More;
 use Carp;
 
@@ -48,13 +50,15 @@ sub import
 
 	# ignore keyboard
 	Gtk2->key_snooper_install (sub { 1; });
+
+	# turn on strict and warnings in caller
+	$^W = 1;
+	@_ = ();
+	goto &strict::import;
 }
 
 package main;
 
-# these are to make people behave
-use strict;
-use warnings;
 # go ahead and use Gtk2 for them.
 use Gtk2;
 # and obviously they'll need Test::More
@@ -120,6 +124,13 @@ sub ginterfaces_ok {
 }
 
 
+# Inspired by Test::Number::Delta
+sub delta_ok ($$;$) {
+	my ($a, $b, $msg) = @_;
+	ok (abs ($a - $b) < 1e-6, $msg);
+}
+
+
 1;
 __END__
 
@@ -210,6 +221,13 @@ like an isa_ok() in steroids.
 
 =back
 
+=item delta_ok (A, B [, NAME])
+
+Checks that the absolute difference of the numbers A and B is smaller than
+1e-6.
+
+=back
+
 =head1 SEE ALSO
 
 L<perl>(1), L<Gtk2>(3pm).
